@@ -18,7 +18,7 @@ Readonly::Scalar our $PIXELS => 14;
 Readonly::Scalar our $PIXELS_ON_LINE => 3;
 
 # Version.
-our $VERSION = 0.05;
+our $VERSION = 0.06;
 
 # Constructor.
 sub new {
@@ -148,8 +148,7 @@ C<-text>.
 
 =item * C<-char> < CHARACTER >
 
- Foreground color.
- Possible values are defined in Curses::UI::Color.
+ Character for Curses::UI::Number drawing.
  Default value is '█'.
 
 =back
@@ -275,8 +274,13 @@ L<Encode>.
 
 =head1 SEE ALSO
 
-L<Curses::UI>,
-L<Curses::UI::Widget>.
+=over
+
+=item L<Task::Curses::UI>
+
+Install the Curses::UI modules.
+
+=back
 
 =head1 REPOSITORY
 
@@ -290,7 +294,8 @@ L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
-BSD license.
+ © 2014-2015 Michal Špaček
+ BSD 2-Clause License
 
 =head1 DEDICATION
 
@@ -298,6 +303,6 @@ To Czech Perl Workshop 2014 and their organizers.
 
 =head1 VERSION
 
-0.05
+0.06
 
 =cut
